@@ -24,7 +24,7 @@
 
 #include <iomanip>
 #include <gnu_gama/local/network.h>
-#include <gnu_gama/local/pobs/format.h>
+#include <gnu_gama/local/format.h>
 #include <gnu_gama/utf8.h>
 
 namespace GNU_gama { namespace local {
